Rdocumentation
powered by
Learn R Programming
rLTP (version 0.1.2)
isGB18030: Indicate whether the encoding of input string is GB18030.
Description
Indicate whether the encoding of input string is GB18030.
Usage
isGB18030(string, combine = FALSE)
Arguments
string
A character vector.
combine
Whether to combine all the strings.
Value
Logical value.