Rdocumentation
powered by
Learn R Programming
rLTP (version 0.1.2)
isGB2312: Indicate whether the encoding of input string is GB2312.
Description
Indicate whether the encoding of input string is GB2312.
Usage
isGB2312(string, combine = FALSE)
Arguments
string
A character vector.
combine
Whether to combine all the strings.
Value
Logical value.